﻿using Hotline.BatchTask.Notifications;
using Hotline.FlowEngine.Notifications;
using MediatR;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Hotline.BatchTask;
using Hotline.Share.Enums.BatchTask;
using Hotline.Article;
using Hotline.Share.Dtos.Article;
using Hotline.Share.Enums.Article;
using XF.Domain.Authentications;

namespace Hotline.Application.OrderApp.Handlers.OrderDelayHandler;

/// <summary>
/// 延期批量审批任务执行完成
/// </summary>
public class OrderDelayBatchReviewTaskCompetedHandler : INotificationHandler<ApptaskCompletedNotify>
{
    private readonly IApptaskDomainService _apptaskDomainService;
    private readonly ICircularRecordDomainService _circularRecordDomainService;

    public OrderDelayBatchReviewTaskCompetedHandler(
        IApptaskDomainService apptaskDomainService,
        ICircularRecordDomainService circularRecordDomainService)
    {
        _apptaskDomainService = apptaskDomainService;
        _circularRecordDomainService = circularRecordDomainService;
    }

    /// <summary>Handles a notification</summary>
    /// <param name="notification">The notification</param>
    /// <param name="cancellationToken">Cancellation token</param>
    public async Task Handle(ApptaskCompletedNotify notification, CancellationToken cancellationToken)
    {
        if(notification.ApptaskItem.TaskType is not ETaskType.OrderDelay) return;

        var progress = await _apptaskDomainService.GetProgressAsync(notification.ApptaskItem.ApptaskId, cancellationToken);
        await _circularRecordDomainService.AddCircularMessage(new AddCircularDto
        {
            Title = $"{progress.Name} 执行完成",
            Content = $"总共：{progress.Total}条数据，成功：{progress.Succeeded}条，失败：{progress.Failed}条",
            CircularTypeId = "5",
            CircularTypeName = "系统消息",
            CircularType = ECircularType.Person,
            IsMustRead = false,
            SourceOrgId = progress.CreatorId,
            SourceOrgName = progress.CreatorName,
            CircularReadGroups = new List<CircularReadGroupDto>
            {
                new()
                {
                    UserId = progress.CreatorId,
                    UserName = progress.CreatorName
                }
            }
        }, cancellationToken);
    }
}